@@ -5,6 +5,8 @@ from future import standard_library
 
 standard_library.install_aliases()  # noqa: E402
 
+import logging
+
 from PyTango.server import server_run
 from tango_simlib.tango_sim_generator import (
     configure_device_models,
@@ -12,12 +14,15 @@ from tango_simlib.tango_sim_generator import (
 )
 
 
+MODULE_LOGGER = logging.getLogger(__name__)
+
+
 def main():
     sim_data_files = [
         "../tests/config_files/MkatVds.xmi",
         "../tests/config_files/MkatVds_SimDD.json",
     ]
-    model = configure_device_models(sim_data_files)
+    model = configure_device_models(sim_data_files, logger=MODULE_LOGGER)
     TangoDeviceServers = get_tango_device_server(model, sim_data_files)
     server_run(TangoDeviceServers)
 
