@@ -32,7 +32,7 @@ from tango import (
     DevState,
     UserDefaultAttrProp,
 )
-from tango.server import Device, DeviceMeta, attribute
+from tango.server import Device, attribute, device_property
 from tango_simlib.model import (
     INITIAL_CONSTANT_VALUE_TYPES,
     Model,
@@ -254,12 +254,19 @@ def get_tango_device_server(models, sim_data_files):
     class TangoDeviceServer(TangoDeviceServerBase, TangoDeviceServerStaticAttrs):
         _models = models
 
+        min_update_period = device_property(
+            dtype=float,
+            default_value=0.99,
+            doc="Minimum time before model update method can be called again [seconds].",
+        )
+
         def init_device(self):
             super(TangoDeviceServer, self).init_device()
             self.model = self._models[self.get_name()]
             self._not_added_attributes = []
             write_device_properties_to_db(self.get_name(), self.model)
             self.model.reset_model_state()
+            self.model.min_update_period = self.min_update_period
             self.initialize_dynamic_commands()
 
         def initialize_dynamic_commands(self):
@@ -419,8 +426,8 @@ def get_parser_instance(sim_datafile):
     return parser_instance
 
 
-def configure_device_model(sim_data_file=None, test_device_name=None):
-    models = configure_device_models(sim_data_file, test_device_name)
+def configure_device_model(sim_data_file=None, test_device_name=None, logger=None):
+    models = configure_device_models(sim_data_file, test_device_name, logger)
     if len(models) == 1:
         return models
     else:
@@ -433,7 +440,7 @@ def configure_device_model(sim_data_file=None, test_device_name=None):
         )
 
 
-def configure_device_models(sim_data_file=None, test_device_name=None):
+def configure_device_models(sim_data_file=None, test_device_name=None, logger=None):
     """
     In essence this function should get the data descriptor file, parse it,
     take the attribute and command information, populate the model(s) quantities and
@@ -482,9 +489,9 @@ def configure_device_models(sim_data_file=None, test_device_name=None):
     models = {}
     if dev_names:
         for dev_name in dev_names:
-            models[dev_name] = Model(dev_name)
+            models[dev_name] = Model(dev_name, logger=logger)
     else:
-        models[dev_name] = Model(dev_name)
+        models[dev_name] = Model(dev_name, logger=logger)
 
     # In case there is more than one parser instance for each file
     for model in models.values():
